ServerConfig

Struct ServerConfig 

pub struct ServerConfig {
    pub server: ServerSettings,
    pub cache: CacheConfig,
    pub logging: LoggingConfig,
}
Complete server configuration

Fields

server: ServerSettings

Server settings

cache: CacheConfig

Cache configuration

logging: LoggingConfig

Logging configuration

Implementations

Source

impl ServerConfig

pub fn load(args: ServerArgs) -> Result<Self, ConfigError>

Load configuration from multiple sources in order of precedence:

  1. Command line arguments (highest priority)
  2. Environment variables
  3. Configuration file
  4. Default values (lowest priority)
pub fn load_and_validate_strict(args: ServerArgs) -> Result<Self, ConfigError>

Load and validate configuration file strictly without fallbacks. This method should be used when validating configuration files. It will return an error if the file has invalid syntax or values.

pub fn validate(&self) -> Result<(), ConfigError>

Validate the configuration

pub fn socket_addr(&self) -> Result<SocketAddr, ConfigError>

Get the server socket address

pub fn log_level(&self) -> Level

Get the logging level as a tracing Level

pub fn print_config(&self)

Print the configuration for debugging