pub struct ServerConfig {
pub server: ServerSettings,
pub database: DatabaseSettings,
pub cache: CacheConfig,
pub logging: LoggingConfig,
}Expand description
Complete server configuration
Fields
server: ServerSettingsServer settings
database: DatabaseSettingsDatabase settings
cache: CacheConfigCache configuration
logging: LoggingConfigLogging configuration
Implementations
Sourceimpl ServerConfig
impl ServerConfig
Sourcepub fn load(args: ServerArgs) -> Result<Self, ConfigError>
pub fn load(args: ServerArgs) -> Result<Self, ConfigError>
Load configuration from multiple sources in order of precedence:
- Command line arguments (highest priority)
- Environment variables
- Configuration file
- Default values (lowest priority)
Sourcepub fn load_and_validate_strict(args: ServerArgs) -> Result<Self, ConfigError>
pub fn load_and_validate_strict(args: ServerArgs) -> Result<Self, ConfigError>
Load and validate configuration file strictly without fallbacks. This method should be used when validating configuration files. It will return an error if the file has invalid syntax or values.
Sourcepub fn validate(&self) -> Result<(), ConfigError>
pub fn validate(&self) -> Result<(), ConfigError>
Validate the configuration
Sourcepub fn socket_addr(&self) -> Result<SocketAddr, ConfigError>
pub fn socket_addr(&self) -> Result<SocketAddr, ConfigError>
Get the server socket address
Sourcepub fn print_config(&self)
pub fn print_config(&self)
Print the configuration for debugging