pub struct ModelDatabase { /* private fields */ }Expand description
SQLite-based model status tracker for distributed systems
Implementations
Sourceimpl ModelDatabase
impl ModelDatabase
Sourcepub fn new(database_path: &str) -> Result<Self, Box<dyn Error>>
pub fn new(database_path: &str) -> Result<Self, Box<dyn Error>>
Create a new database instance and initialize the schema
Sourcepub fn get_status(&self, model_name: &str) -> SqliteResult<Option<ModelStatus>>
pub fn get_status(&self, model_name: &str) -> SqliteResult<Option<ModelStatus>>
Get the status of a model
Sourcepub fn get_model_record(
&self,
model_name: &str,
) -> SqliteResult<Option<ModelRecord>>
pub fn get_model_record( &self, model_name: &str, ) -> SqliteResult<Option<ModelRecord>>
Get the full record for a model
Sourcepub fn set_status(
&self,
model_name: &str,
provider: ModelProvider,
status: ModelStatus,
message: Option<String>,
) -> SqliteResult<()>
pub fn set_status( &self, model_name: &str, provider: ModelProvider, status: ModelStatus, message: Option<String>, ) -> SqliteResult<()>
Set the status of a model, creating or updating the record
Sourcepub fn touch_model(&self, model_name: &str) -> SqliteResult<()>
pub fn touch_model(&self, model_name: &str) -> SqliteResult<()>
Update the last_used_at timestamp for a model
Sourcepub fn delete_model(&self, model_name: &str) -> SqliteResult<()>
pub fn delete_model(&self, model_name: &str) -> SqliteResult<()>
Delete a model record
Sourcepub fn get_models_by_last_used(
&self,
limit: Option<u32>,
) -> SqliteResult<Vec<ModelRecord>>
pub fn get_models_by_last_used( &self, limit: Option<u32>, ) -> SqliteResult<Vec<ModelRecord>>
Get models ordered by last used (oldest first) - for future LRU cleanup
Sourcepub fn get_status_counts(&self) -> SqliteResult<(u32, u32, u32)>
pub fn get_status_counts(&self) -> SqliteResult<(u32, u32, u32)>
Get count of models with each status - for monitoring
Sourcepub fn try_claim_for_download(
&self,
model_name: &str,
provider: ModelProvider,
) -> SqliteResult<ModelStatus>
pub fn try_claim_for_download( &self, model_name: &str, provider: ModelProvider, ) -> SqliteResult<ModelStatus>
Atomically attempt to claim a model for downloading using compare-and-swap semantics Returns the current status of the model:
- If model doesn’t exist, creates it with DOWNLOADING status and returns DOWNLOADING
- If model exists, returns its current status without modification This prevents race conditions in distributed environments