pub struct ModelDownloadTracker { /* private fields */ }Expand description
Tracks the status of model downloads using SQLite for persistence
Implementations
Sourceimpl ModelDownloadTracker
impl ModelDownloadTracker
pub fn new() -> Self
Sourcepub fn get_status(&self, model_name: &str) -> Option<ModelStatus>
pub fn get_status(&self, model_name: &str) -> Option<ModelStatus>
Gets the status of a model from the database If the model is not in the database, it returns None
Sourcepub fn set_status_and_notify(
&self,
model_name: String,
status: ModelStatus,
provider: ModelProvider,
message: Option<String>,
)
pub fn set_status_and_notify( &self, model_name: String, status: ModelStatus, provider: ModelProvider, message: Option<String>, )
Sets the status of a model and notifies all waiting channels
Sourcepub fn set_status(
&self,
model_name: String,
status: ModelStatus,
provider: ModelProvider,
)
pub fn set_status( &self, model_name: String, status: ModelStatus, provider: ModelProvider, )
Sets the status of a model
Sourcepub fn add_waiting_channel(
&self,
model_name: &str,
tx: Sender<Result<ModelStatusUpdate, Status>>,
)
pub fn add_waiting_channel( &self, model_name: &str, tx: Sender<Result<ModelStatusUpdate, Status>>, )
Adds a channel to wait for updates on a specific model
Sourcepub fn delete_status(&self, model_name: &str)
pub fn delete_status(&self, model_name: &str)
Deletes the status of a model from the database This is used when a model is removed from the tracker
Sourcepub async fn ensure_model_downloaded(
&self,
model_name: &str,
provider: ModelProvider,
tx: &Sender<Result<ModelStatusUpdate, Status>>,
ignore_weights: bool,
) -> ModelStatus
pub async fn ensure_model_downloaded( &self, model_name: &str, provider: ModelProvider, tx: &Sender<Result<ModelStatusUpdate, Status>>, ignore_weights: bool, ) -> ModelStatus
Initiates a download for a model and streams status updates